# Changelog

## [0.1.3](https://github.com/open-feature/python-sdk-contrib/compare/openfeature-hooks-opentelemetry/v0.1.2...openfeature-hooks-opentelemetry/v0.1.3) (2024-03-17)


### 📚 Documentation

* fix add_hooks call in otel hooks README ([#68](https://github.com/open-feature/python-sdk-contrib/issues/68)) ([8f26275](https://github.com/open-feature/python-sdk-contrib/commit/8f26275a1504086effeb1ca92817671bf9ac27ff))

## [0.1.2](https://github.com/open-feature/python-sdk-contrib/compare/openfeature-hooks-opentelemetry/v0.1.1...openfeature-hooks-opentelemetry/v0.1.2) (2024-03-13)


### 📚 Documentation

* update OTel hook readme with correct import paths ([#65](https://github.com/open-feature/python-sdk-contrib/issues/65)) ([689662b](https://github.com/open-feature/python-sdk-contrib/commit/689662b59ac6117314d707322f26ab4f7b216cc0))

## [0.1.1](https://github.com/open-feature/python-sdk-contrib/compare/openfeature-hooks-opentelemetry-v0.1.0...openfeature-hooks-opentelemetry/v0.1.1) (2024-03-11)


### 📚 Documentation

* update OpenTelemetry hook README ([#49](https://github.com/open-feature/python-sdk-contrib/issues/49)) ([02157f4](https://github.com/open-feature/python-sdk-contrib/commit/02157f447ac7b4dfd7ceced3c6808cf512c680f0))


### 🔄 Refactoring

* move OTel hooks to openfeature.contrib.hook ([#64](https://github.com/open-feature/python-sdk-contrib/issues/64)) ([7075656](https://github.com/open-feature/python-sdk-contrib/commit/707565669cfaf134fe445d54c26e0643756f7f8c))
